##  Building Initial Data Repository
  * Ensure minimum essential data in the SAP LeanIX inventory
    * Start with and model applications, business capabilities, and organizations.
    * Ensure applications are linked to the business capabilities they support.
    * In application fact sheets, ensure lifecycle data and the responsible subscriber are documented.
  * Define standard process architecture in SAP Signavio
    * Create end-to-end processes with defined value steps that describe the end-to-end value flow within the organization.
    * Cluster functional sub-processes within functional sections to promote process harmonization and reusability within the E2E flow, as well as role-based process clustering.
